@@ -1,9 +1,9 @@
 package Code::Includable::Tree::FromStruct;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-06'; # DATE
+our $DATE = '2021-07-02'; # DATE
 our $DIST = 'Role-TinyCommons-Tree'; # DIST
-our $VERSION = '0.126'; # VERSION
+our $VERSION = '0.127'; # VERSION
 
 use strict;
 our $GET_PARENT_METHOD = 'parent';
@@ -87,7 +87,7 @@ Code::Includable::Tree::FromStruct - Routine to build tree object from data stru
 
 =head1 VERSION
 
-This document describes version 0.126 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2021-05-06.
+This document describes version 0.127 of Code::Includable::Tree::FromStruct (from Perl distribution Role-TinyCommons-Tree), released on 2021-07-02.
 
 =for Pod::Coverage .+
 
@@ -135,7 +135,7 @@ Source repository is at L<https://github.com/perlancar/perl-Role-TinyCommons-Tre
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Role-TinyCommons-TreeNode/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Role-TinyCommons-Tree>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
